searchData={"items":[{"type":"module","title":"Murmur","doc":"This module implements the x86_32, x86_128 and x64_128 variants of the\nnon-cryptographic hash Murmur3.","ref":"Murmur.html"},{"type":"module","title":"Examples - Murmur","doc":"iex> Murmur.hash_x86_32(\"b2622f5e1310a0aa14b7f957fe4246fa\", 2147368987)\n    3297211900\n\n    iex> Murmur.hash_x86_128(\"some random data\")\n    217376041865091047320520964146365461062\n\n    # hashes of Erlang terms may change between Erlang versions\n    # iex> Murmur.hash_x64_128([:yes, :you, :can, :use, :any, :Erlang, :term!])\n    # => 300414073828138369336317731503972665325","ref":"Murmur.html#module-examples"},{"type":"function","title":"Murmur.hash_x64_128/2","doc":"Returns the hashed Erlang term `data` using an optional `seed` which defaults to `0`.\n\nThis function uses the x64 128bit variant.","ref":"Murmur.html#hash_x64_128/2"},{"type":"function","title":"Murmur.hash_x86_32/2","doc":"Returns the hashed Erlang term `data` using an optional `seed` which defaults to `0`.\n\nThis function uses the x86 32bit variant.","ref":"Murmur.html#hash_x86_32/2"},{"type":"function","title":"Murmur.hash_x86_128/2","doc":"Returns the hashed Erlang term `data` using an optional `seed` which defaults to `0`.\n\nThis function uses the x86 128bit variant.","ref":"Murmur.html#hash_x86_128/2"},{"type":"module","title":"Murmur.Hash128X64","doc":"","ref":"Murmur.Hash128X64.html"},{"type":"function","title":"Murmur.Hash128X64.hash_x64_128/2","doc":"","ref":"Murmur.Hash128X64.html#hash_x64_128/2"},{"type":"module","title":"Murmur.Hash128X86","doc":"","ref":"Murmur.Hash128X86.html"},{"type":"function","title":"Murmur.Hash128X86.hash_x86_128/2","doc":"","ref":"Murmur.Hash128X86.html#hash_x86_128/2"},{"type":"module","title":"Murmur.Hash32X86","doc":"","ref":"Murmur.Hash32X86.html"},{"type":"function","title":"Murmur.Hash32X86.hash_x86_32/2","doc":"","ref":"Murmur.Hash32X86.html#hash_x86_32/2"},{"type":"module","title":"Murmur.Helpers","doc":"","ref":"Murmur.Helpers.html"},{"type":"function","title":"Murmur.Helpers.bxor_and_shift_right/2","doc":"","ref":"Murmur.Helpers.html#bxor_and_shift_right/2"},{"type":"function","title":"Murmur.Helpers.fmix32/1","doc":"","ref":"Murmur.Helpers.html#fmix32/1"},{"type":"function","title":"Murmur.Helpers.fmix64/1","doc":"","ref":"Murmur.Helpers.html#fmix64/1"},{"type":"function","title":"Murmur.Helpers.k_32_op/4","doc":"","ref":"Murmur.Helpers.html#k_32_op/4"},{"type":"function","title":"Murmur.Helpers.k_64_op/4","doc":"","ref":"Murmur.Helpers.html#k_64_op/4"},{"type":"macro","title":"Murmur.Helpers.mask_32/1","doc":"","ref":"Murmur.Helpers.html#mask_32/1"},{"type":"macro","title":"Murmur.Helpers.mask_64/1","doc":"","ref":"Murmur.Helpers.html#mask_64/1"},{"type":"function","title":"Murmur.Helpers.rotl32/2","doc":"","ref":"Murmur.Helpers.html#rotl32/2"},{"type":"function","title":"Murmur.Helpers.rotl64/2","doc":"","ref":"Murmur.Helpers.html#rotl64/2"},{"type":"function","title":"Murmur.Helpers.swap_uint/1","doc":"","ref":"Murmur.Helpers.html#swap_uint/1"},{"type":"extras","title":"Murmur","doc":"Murmur\n======\n\n[![test](https://github.com/preciz/murmur/actions/workflows/test.yml/badge.svg)](https://github.com/preciz/murmur/actions/workflows/test.yml)\n\nMurmur is a pure Elixir implementation of the non-cryptographic hash [Murmur3](https://code.google.com/p/smhasher/wiki/MurmurHash3).\n\nIt aims to implement the x86_32bit, x86_128bit and x64_128bit variants.\n\n# Usage\n\nAdd Murmur as a dependency in your mix.exs file.\n\n```elixir\ndef deps do\n  [{:murmur, \"~> 2.0\"}]\nend\n```\n\n# Examples\n\n```elixir\niex> Murmur.hash_x86_32(\"b2622f5e1310a0aa14b7f957fe4246fa\", 2147368987)\n3297211900\n\niex> Murmur.hash_x86_128(\"some random data\")\n5586633072055552000169173700229798482\n\n# hashes of Erlang terms may change between Erlang versions\niex> Murmur.hash_x64_128([:yes, :you, :can, :use, :any, :erlang, :term!])\n300414073828138369336317731503972665325\n```\n\n# Performance\n\nThis implementation achieves the following ips (iterations per second) with a 50-byte long binary input:\n\n```txt\nCPU Information: AMD Ryzen 7 8845HS w\nNumber of Available Cores: 16\nElixir 1.17.2\nErlang 27.0\nJIT enabled: true\n\nName                          ips        average  deviation         median         99th %\nMurmur.hash_x86_32      1657.86 K        0.60 μs    ±86.24%        0.59 μs        0.81 μs\nMurmur.hash_x86_128      776.07 K        1.29 μs  ±1061.39%        1.21 μs        1.49 μs\nMurmur.hash_x64_128      496.00 K        2.02 μs   ±459.12%        1.91 μs        2.62 μs\n```","ref":"readme.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}